==> members-facade-2.1.2-20210128.021717-45-sources.jar: com/bizvane/members/facade/service/api/MbrLevelRechargeService.java <==
package com.bizvane.members.facade.service.api;


import com.bizvane.members.facade.models.PayLevelRechargeSearchRequestVO;
import com.bizvane.members.facade.models.PayLevelRechargeSearchResponseVO;
import com.bizvane.members.facade.models.po.MbrLevelRechargeRecordPO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Optional;

public interface MbrLevelRechargeService {


    ResponseData<PageInfo<PayLevelRechargeSearchResponseVO>> getPayLevelRechargeList(PayLevelRechargeSearchRequestVO payLevelRechargeSearchRequestVO);


    ResponseData<String> exportPayLevelRechargeList(PayLevelRechargeSearchRequestVO payLevelRechargeSearchRequestVO, Optional<SysAccountPO> optional);

    /**
     * 充值立即发券
     * 给365充值会员发券
     * @param mp
     * @return
     * @throws Exception
     */
    Boolean sendImmediatelyCoupon(MbrLevelRechargeRecordPO mp) throws Exception;

    /**
     * 任务发券
     * 给365充值会员发券
     * @param mp
     * @return
     * @throws Exception
     */
    Boolean sendCoupon(MbrLevelRechargeRecordPO mp) throws Exception;


    /**
     * 付费会员卡等级充值退款
     * @param levelRechargeRecordId
     * @param sysAccountPO
     * @return
     */
    ResponseData<String> refundPayLevelRecharge(Long levelRechargeRecordId, SysAccountPO sysAccountPO);

    /**
     * 付费会员卡等级充值记录查询
     * @param payLevelRechargeSearchRequestVO
     * @return
     */
    ResponseData<List<PayLevelRechargeSearchResponseVO>> getPLRechargeList(PayLevelRechargeSearchRequestVO payLevelRechargeSearchRequestVO);

    /**
     * 付费会员卡退款回调
     *
     * @param req
     * @param res
     * @return
     */
    String levelRefundCallBack(HttpServletRequest req, HttpServletResponse res);
}

==> members-facade-20250610-20250722.062253-1-sources.jar: com/bizvane/members/facade/service/api/MbrLevelRechargeService.java <==
package com.bizvane.members.facade.service.api;


import com.bizvane.members.facade.models.PayLevelRechargeSearchRequestVO;
import com.bizvane.members.facade.models.PayLevelRechargeSearchResponseVO;
import com.bizvane.members.facade.models.po.MbrLevelRechargeRecordPO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Optional;

public interface MbrLevelRechargeService {


    ResponseData<PageInfo<PayLevelRechargeSearchResponseVO>> getPayLevelRechargeList(PayLevelRechargeSearchRequestVO payLevelRechargeSearchRequestVO);

    @Deprecated
    ResponseData<String> exportPayLevelRechargeList(PayLevelRechargeSearchRequestVO payLevelRechargeSearchRequestVO, Optional<SysAccountPO> optional);

    /**
     * 导出会员付费卡购买记录
     * @param payLevelRechargeSearchRequestVO
     * @param currentUser
     * @return
     */
    ResponseData exportPayLevelRechargeList(PayLevelRechargeSearchRequestVO payLevelRechargeSearchRequestVO, SysAccountPO currentUser);

    /**
     * 充值立即发券
     * 给365充值会员发券
     * @param mp
     * @return
     * @throws Exception
     */
    Boolean sendImmediatelyCoupon(MbrLevelRechargeRecordPO mp) throws Exception;

    Boolean sendInstantCoupon(MbrLevelRechargeRecordPO record) throws Exception;

    /**
     * 任务发券
     * 给365充值会员发券
     * @param mp
     * @return
     * @throws Exception
     */
    Boolean sendCoupon(MbrLevelRechargeRecordPO mp) throws Exception;


    /**
     * 付费会员卡等级充值退款
     * @param levelRechargeRecordId
     * @param sysAccountPO
     * @return
     */
    ResponseData<String> refundPayLevelRecharge(Long levelRechargeRecordId, SysAccountPO sysAccountPO);

    /**
     * 付费会员卡等级充值记录查询
     * @param payLevelRechargeSearchRequestVO
     * @return
     */
    ResponseData<List<PayLevelRechargeSearchResponseVO>> getPLRechargeList(PayLevelRechargeSearchRequestVO payLevelRechargeSearchRequestVO);

    /**
     * 付费会员卡退款回调
     *
     * @param req
     * @param res
     * @return
     */
    String levelRefundCallBack(HttpServletRequest req, HttpServletResponse res);

    boolean sendCouponNextMonth(MbrLevelRechargeRecordPO mp)throws Exception;
}
